############################################################
#                                                          #
#                   Time series                            #
#                                                          #
############################################################

#-------------------------------------------------------------------------------
# Plot per una estació determinada, en aquest cas: colnames(llista_uk_total)[1]

data_single     <- data.frame(date      = date_times,
                              observations       = df_obs_sub[ ,colnames(llista_uk_total)[1] ],
                              Model              = llista_uk_total_df[ ,colnames(llista_uk_total)[1]], 
                              Model_corrected    = LOOCV_total_df[ ,colnames(llista_uk_total)[1]])


openair::timePlot(selectByDate(data_single, year = 2021, month = 'January'),
                    pollutant = c("observations","Model","Model_corrected"),
                    group = TRUE,
                    y.relation = "free",
                    ylab="NO2 (ug/m3)",
                    cols = c("black", "blue", "grey"),
                    lty = c("dotted","solid","dashed"),
                    lwd = c(3,2,2),
                    name.pol = c("observations","Raw model", "Corrected Model"))

#-------------------------------------------------------------------------------
# Plot per cada estació:

# month_names = c("January","February","March","April","May","June","July","August",
#                 "September","October","November","December")

month_names = c("January")

  
for (l in 1:nrow(local_stations)) {
  data_single     <- data.frame(date               = date_times,
                                observations       = df_obs_sub[ ,colnames(llista_uk_total)[l]],
                                Model              = llista_uk_total_df[ ,colnames(llista_uk_total)[l]], 
                                Model_corrected    = LOOCV_total_df[ ,colnames(llista_uk_total)[l]]) 
  for (mm in month_names) {
    # TIME_PLOT
    png(file = paste0(Images1,"timeplot_",df_obs_sub[ ,colnames(llista_uk_total)[l]],"_",mm,"_24h.png"), width = 800, height = 400)
    openair::timePlot(selectByDate(data_single, year = 2021, month = mm),
                      pollutant = c("observations","Model","Model_corrected"),
                      group = TRUE,
                      y.relation = "free",
                      ylab="NO2 (ug/m3)",
                      cols = c("black", "blue", "grey"),
                      lty = c("dotted","solid","dashed"),
                      lwd = c(3,2,2), 
                      name.pol = c("Observations","Raw model", "Corrected Model"))
    dev.off()
}
}

#-------------------------------------------------------------------------------
# Plot per la mitjana horària de totes les estacions:

#First, we create a matrix to put the data of observations and model (corrected and raw)
obs_total            <- matrix(nrow = 24, ncol = 0) 
raw_model_total      <- matrix(nrow = 24, ncol = 0)
corr_model_total     <- matrix(nrow = 24, ncol = 0)

for (i in 1:nrow(local_stations)) {
  obs_estacio           <-  df_obs_sub[ ,colnames(llista_uk_total)[i]]
  raw_model_estacio     <-  llista_uk_total_df[ ,colnames(llista_uk_total)[i]]
  corr_model_estacio    <-  LOOCV_total_df[ ,colnames(llista_uk_total)[i]]
  
  obs_total             <- cbind(obs_total,obs_estacio)
  raw_model_total       <- cbind(raw_model_total,raw_model_estacio)
  corr_model_total      <- cbind(corr_model_total,corr_model_estacio)
}

#Then, we calculate the means of each hour considering the whole stations
raw_model   <- data.frame( obs = rowMeans(obs_total,na.rm=TRUE),
                         mod = rowMeans(raw_model_total,na.rm=TRUE),
                         model="raw_model")

corr_model   <- data.frame( obs = rowMeans(obs_total,na.rm=TRUE),
                          mod = rowMeans(corr_model_total,na.rm=TRUE),
                          model="corr_model")

data_single   <- data.frame(date      = date_times,
                              observations       = raw_model$obs,
                              Model              = raw_model$mod,
                              Model_corrected    = corr_model$mod)

#Finally, we plot the time series 
# month_names = c("January","February","March","April","May","June","July","August",
#                 "September","October","November","December")

month_names = c("January")

openair::timePlot(selectByDate(data_single, year = 2021, month = 'January'),
                  pollutant = c("observations","Model","Model_corrected"),
                  group = TRUE,
                  y.relation = "free",
                  ylab="NO2 (ug/m3)",
                  cols = c("black", "blue", "grey"),
                  lty = c("dotted","solid","dashed"),
                  lwd = c(3,2,2),
                  name.pol = c("observations","Raw model", "Corrected Model"))

